@@ -30,8 +30,10 @@ class LLM(Step):
                 **self.inputs,
             )
         ).run()
-        return exclude_none_dict(dict(
-            prompts=prepare_prompt_outputs.get("prompts"),
-            openai_responses=call_llm_outputs.get("openai_responses"),
-            extracted_responses=extract_model_response_outputs.get("extracted_responses"),
-        ))
+        return exclude_none_dict(
+            dict(
+                prompts=prepare_prompt_outputs.get("prompts"),
+                openai_responses=call_llm_outputs.get("openai_responses"),
+                extracted_responses=extract_model_response_outputs.get("extracted_responses"),
+            )
+        )
